@@ -1,18 +1,20 @@
 import unittest
 from unittest.mock import MagicMock
-import math
 
 from osgar.followme import FollowMe, EmergencyStopException
-from osgar.bus import BusHandler
+from osgar.bus import Bus
 
 
 class FollowMeTest(unittest.TestCase):
 
     def test_usage(self):
-        bus = BusHandler(name='app', logger=MagicMock)
-        app = FollowMe(config={}, bus=bus)
+        bus = Bus(MagicMock())
+        app = FollowMe(config={}, bus=bus.handle('app'))
+        tester = bus.handle('tester')
+        tester.register('emergency_stop')
+        bus.connect('tester.emergency_stop', 'app.emergency_stop')
+        tester.publish('emergency_stop', True)
 
-        bus.queue.put((0, 'emergency_stop', True))
         app.raise_exception_on_stop = True
         
         with self.assertRaises(EmergencyStopException):
